import {
  Accordion,
  AccordionContent,
  AccordionItem,
  AccordionTrigger,
} from "@/components/ui/accordion";
import parse from "html-react-parser";
import styles from "./JobCardDescription.module.css";
import Image from "next/image";
import JobCardIconContainer from "./JobCardIconContainer";
import { Button } from "@/components/ui/button";

interface JobPosting {
  title: string;
  logo: string;
  company: string;
  location: string;
  type: string;
  description: string;
  link: string;
  skills: {
    react: boolean;
    python: boolean;
    golang: boolean;
    svelte: boolean;
    nextjs: boolean;
    typescript: boolean;
    tailwind: boolean;
  };
}

export default async function JobCard(props: { job: JobPosting }) {
  const { title, logo, company, location, type, description, link, skills } =
    props.job;
  const parsedDescription = parse(description);
  const hasAnySkill = Object.values(skills).some((skill) => skill);

  return (
    <Accordion type="single" collapsible>
      <AccordionItem value={title}>
        <AccordionTrigger>
          <div className="flex justify-between w-full">
            <div className="flex flex-row items-center gap-4">
              <Image
                className="max-h-12 w-auto"
                src={logo}
                alt={`${company}'s logo`}
                width={100}
                height={100}
              />
              <div className="flex flex-col justify-start">
                <h2 className="text-xl sm:text-2xl text-left block sm:hidden">
                  {title.length > 50 ? title.slice(0, 50) + "..." : title}
                </h2>
                <h2 className="text-xl sm:text-2xl text-left sm:block hidden">
                  {title}
                </h2>

                <div className="text-left items-center text-sm sm:text-base space-x-4">
                  <span className="">{company}</span>
                  <span className="text-xs sm:text-sm  text-stone-500">
                    {location}
                  </span>
                  <span className="text-xs sm:text-sm  text-stone-500">
                    {type}
                  </span>
                </div>
              </div>
            </div>
            <div className="flex justify-end items-center gap-2">
              {hasAnySkill && <JobCardIconContainer skills={skills} />}
            </div>
          </div>
        </AccordionTrigger>
        <AccordionContent>
          <div className="flex flex-col gap-2">
            <div className={`py-4 ${styles.parsedDescription}`}>
              {parsedDescription}
            </div>
            <div className="flex justify-center">
              <a href={link}>
                <Button variant="outline">Apply here</Button>
              </a>
            </div>
          </div>
        </AccordionContent>
      </AccordionItem>
    </Accordion>
  );
}
